### SI Person Object maker

PyPi package which will make random person object with Slovenian names, last names, addresses  🪧, zip codes 👾 and City 🏦🏢 names.



How to use it:

```python
from src.si_person_maker.person import Person

p = Person()

p.name  # will return random Slovenian name
p.last_name  # will return random Slovenian last name 
p.address  # will return random Slovenian street name with r
# andom house number

p.zip_city  # will return random Slovenian City name with random zip code
```




## Author: Miha Novak  | Email: miha.novak@outlook.de
